@@ -5,8 +5,8 @@ from yaml.scanner import ScannerError
 
 from modules.global_variables import *
 from modules.logger import log_critical_error, create_directory_if_not_exists
-from safetypy import safetypy as sp
-
+# from safetypy import safetypy as sp
+import modules.safetypy as sp
 
 def load_setting_api_access_token(logger, config_settings):
     """
@@ -223,6 +223,8 @@ def get_filename_item_id(logger, config_settings):
 
 def set_env_defaults(name, env_var, logger):
     # if env_var is None or '':
+    if name == 'DB_SERVER' and env_var == 'heroku':
+        return os.environ['DATABASE_URL']
     if not env_var:
         if name == 'CONFIG_NAME':
             logger.error('You must set the CONFIG_NAME')
@@ -237,6 +239,8 @@ def set_env_defaults(name, env_var, logger):
             env_var = None
         else:
             env_var = 'false'
+    if env_var == 'None':
+        env_var = None
     print(name, ' set to ', env_var)
     return env_var
 
@@ -295,6 +299,11 @@ def load_config_settings(logger, path_to_config_file, docker_enabled):
     if docker_enabled is True:
         settings = {
             API_TOKEN: docker_load_setting_api_access_token(logger, os.environ['API_TOKEN']),
+            HEROKU_URL: os.environ.get('HEROKU_POSTGRESQL_OLIVE_URL'),
+            SSL_CERT: set_env_defaults('SSL_CERT', os.environ['SSL_CERT'], logger),
+            SSL_VERIFY: set_env_defaults('SSL_VERIFY', os.environ['SSL_VERIFY'], logger),
+            PROXY_HTTP: set_env_defaults('PROXY_HTTP', os.environ['PROXY_HTTP'], logger),
+            PROXY_HTTPS: set_env_defaults('PROXY_HTTPS', os.environ['PROXY_HTTPS'], logger),
             EXPORT_PATH: None,
             # PREFERENCES: load_setting_preference_mapping(logger, config_settings),
             # FILENAME_ITEM_ID: get_filename_item_id(logger, config_settings),
@@ -415,42 +424,51 @@ def configure(logger, path_to_config_file, export_formats, docker_enabled):
                                  certificate_settings=config_settings[SSL_CERT],
                                  ssl_verify=config_settings[SSL_VERIFY])
 
-    if config_settings[EXPORT_PATH] is not None:
-        if config_settings[CONFIG_NAME] is not None:
-            create_directory_if_not_exists(logger, os.path.join(config_settings[EXPORT_PATH]))
+    if not docker_enabled:
+        if config_settings[EXPORT_PATH] is not None:
+            if config_settings[CONFIG_NAME] is not None:
+                create_directory_if_not_exists(logger, os.path.join(config_settings[EXPORT_PATH]))
+            else:
+                logger.error("You must set the config_name in your config file before continuing.")
+                sys.exit()
+
         else:
-            logger.error("You must set the config_name in your config file before continuing.")
-            sys.exit()
-    else:
-        logger.info('No export path was found in ' + path_to_config_file + ', defaulting to /exports')
-        config_settings[EXPORT_PATH] = os.path.join(os.getcwd(), 'exports')
-        if config_settings[CONFIG_NAME] is not None:
-            create_directory_if_not_exists(logger, os.path.join(config_settings[EXPORT_PATH]))
-        else:
-            logger.error("You must set the config_name in your config file before continuing.")
-            sys.exit()
+            logger.info('No export path was found in ' + path_to_config_file + ', defaulting to /exports')
+            config_settings[EXPORT_PATH] = os.path.join(os.getcwd(), 'exports')
+            if config_settings[CONFIG_NAME] is not None:
+                create_directory_if_not_exists(logger, os.path.join(config_settings[EXPORT_PATH]))
+            else:
+                logger.error("You must set the config_name in your config file before continuing.")
+                sys.exit()
 
     return sc_client, config_settings
 
 
 def rename_config_sample(logger):
-    if os.path.isfile('configs/config.yaml.sample'):
-        file_size = os.stat('configs/config.yaml.sample')
-        file_size = file_size.st_size
-        if file_size <= 666:
-            logger.info('It looks like the config file has not been filled out. Open the folder named "configs" '
-                        'and edit the file named "config.yaml.sample" before continuing')
-            sys.exit()
-        if file_size >= 667:
-            logger.info('It looks like you have edited config.yaml.sample but have not renamed it. Would you like '
-                        'the '
-                        'script to do it for you (recommended!)? If you say no, you will need to manually remove '
-                        '.sample from the file name.  ')
-            question = input('Please type either y (yes) or n (no) and press enter to continue.   ')
-            if question == 'y':
-                os.rename(r'configs/config.yaml.sample', r'configs/config.yaml')
-            else:
+    if not os.path.isfile('configs/config.yaml'):
+        if os.path.isfile('configs/config.yaml.sample'):
+            file_size = os.stat('configs/config.yaml.sample')
+            file_size = file_size.st_size
+            if file_size <= 666:
+                logger.info('It looks like the config file has not been filled out. Open the folder named "configs" '
+                            'and edit the file named "config.yaml.sample" before continuing')
                 sys.exit()
+            if file_size >= 667:
+                logger.info('It looks like you have not renamed "config.yaml.sample" to "config.yaml". Would you like '
+                            'the '
+                            'script to do it for you (recommended!)? If you say no, you will need to manually remove '
+                            '.sample from the file name.  ')
+                question = input('Please type either y (yes) or n (no) and press enter to continue.   ')
+                if question.startswith('y'):
+                    os.rename(r'configs/config.yaml.sample', r'configs/config.yaml')
+                else:
+                    sys.exit()
+            else:
+                logger.info('No config file found. Please either name it config.yaml or specify it with --config.')
+                sys.exit()
+        else:
+            logger.info('No config file found. Please either name it config.yaml or specify it with --config.')
+            sys.exit()
 
 
 def parse_command_line_arguments(logger):
@@ -477,21 +495,23 @@ def parse_command_line_arguments(logger):
                                                              'Directory will be named iAuditor Audit Exports, and will '
                                                              'be placed in your current directory')
     args = parser.parse_args()
+    print(args)
+    if args.docker is None:
+        if args.config is None:
+            rename_config_sample(logger)
 
-    if args.config is None:
-        rename_config_sample(logger)
-
-    if args.config is not None:
-        config_filename = os.path.join('configs', args.config)
-        print(args.config)
-        if os.path.isfile(config_filename):
+        if args.config is not None:
             config_filename = os.path.join('configs', args.config)
-            logger.debug(config_filename + ' passed as config argument')
+            if os.path.isfile(config_filename):
+                config_filename = os.path.join('configs', args.config)
+                logger.debug(config_filename + ' passed as config argument')
+            else:
+                logger.error(config_filename + ' is either missing or corrupt.')
+                sys.exit(1)
         else:
-            logger.error(config_filename + ' is either missing or corrupt.')
-            sys.exit(1)
+            config_filename = os.path.join('configs', DEFAULT_CONFIG_FILENAME)
     else:
-        config_filename = os.path.join('configs', DEFAULT_CONFIG_FILENAME)
+        config_filename = None
 
     export_formats = ['pdf']
     if args.format is not None and len(args.format) > 0:
@@ -508,6 +528,7 @@ def parse_command_line_arguments(logger):
 
     loop_enabled = True if args.loop is not None else False
     docker_enabled = True if args.docker is not None else False
+    print(docker_enabled)
 
     return config_filename, export_formats, args.list_preferences, loop_enabled, docker_enabled
 
